@@ -24,7 +24,16 @@ class WebApp(django.core.handlers.wsgi.WSGIHandler):
         LOG.info("Generating web application...")
         super(WebApp, self).__init__()
         mini_buildd.models.import_all()
-        self._syncdb()
+
+        LOG.info("Migrating database (migrate)...")
+        django.core.management.call_command("migrate", interactive=False, run_syncdb=True, verbosity=0)
+
+        LOG.info("Clean up python-registration (cleanupregistration)...")
+        django.core.management.call_command("cleanupregistration", interactive=False, verbosity=0)
+
+        # django 1.8 no longer per default runs this; Doing this once, manually
+        LOG.info("Run django internal checks (check)...")
+        django.core.management.call_command("check")
 
     @classmethod
     def set_admin_password(cls, password):
@@ -63,12 +72,6 @@ class WebApp(django.core.handlers.wsgi.WSGIHandler):
             mini_buildd.models.chroot.Chroot.mbd_get_prepared(),
             "remove")
 
-    @classmethod
-    def _syncdb(cls):
-        LOG.info("Syncing database...")
-        django.core.management.call_command("syncdb", interactive=False, verbosity=0)
-        django.core.management.call_command("cleanupregistration", interactive=False, verbosity=0)
-
     @classmethod
     def loaddata(cls, file_name):
         django.core.management.call_command("loaddata", file_name)
